@@ -29,7 +29,7 @@
 
 #include <glib/gi18n.h>
 
-G_DEFINE_DYNAMIC_TYPE (CcMousePanel, cc_mouse_panel, CC_TYPE_PANEL)
+CC_PANEL_REGISTER (CcMousePanel, cc_mouse_panel)
 
 #define MOUSE_PANEL_PRIVATE(o) \
   (G_TYPE_INSTANCE_GET_PRIVATE ((o), CC_TYPE_MOUSE_PANEL, CcMousePanelPrivate))
@@ -125,16 +125,10 @@ cc_mouse_panel_class_init (CcMousePanelClass *klass)
   object_class->dispose = cc_mouse_panel_dispose;
 }
 
-static void
-cc_mouse_panel_class_finalize (CcMousePanelClass *klass)
-{
-}
-
 /* Toggle between mouse panel properties and testing area. */
 static void
 shell_test_button_toggle_event (GtkToggleButton *button, CcMousePanel *panel)
 {
-  GtkBuilder *dialog = panel->priv->builder;
   GtkNotebook *notebook = GTK_NOTEBOOK (panel->priv->widget);
   gint page_num;
 
